@@ -1,7 +1,7 @@
 <?php
 /*
 
-@version   v5.20.14  06-Jan-2019
+@version   v5.20.19  13-Dec-2020
 @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
 @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
   Latest version is available at http://adodb.org/
@@ -46,7 +46,7 @@ class ADODB_Active_Table {
 
 // $db = database connection
 // $index = name of index - can be associative, for an example see
-//    http://phplens.com/lens/lensforum/msgs.php?id=17790
+//    PHPLens Issue No: 17790
 // returns index into $_ADODB_ACTIVE_DBS
 function ADODB_SetDatabaseAdapter(&$db, $index=false)
 {
@@ -120,7 +120,7 @@ class ADODB_Active_Record {
 	// php5 constructor
 	function __construct($table = false, $pkeyarr=false, $db=false)
 	{
-	global $ADODB_ASSOC_CASE,$_ADODB_ACTIVE_DBS;
+	global $_ADODB_ACTIVE_DBS;
 
 		if ($db == false && is_object($pkeyarr)) {
 			$db = $pkeyarr;
@@ -374,7 +374,7 @@ class ADODB_Active_Record {
 	// update metadata
 	function UpdateActiveTable($pkeys=false,$forceUpdate=false)
 	{
-	global $ADODB_ASSOC_CASE,$_ADODB_ACTIVE_DBS , $ADODB_CACHE_DIR, $ADODB_ACTIVE_CACHESECS;
+	global $_ADODB_ACTIVE_DBS , $ADODB_CACHE_DIR, $ADODB_ACTIVE_CACHESECS;
 	global $ADODB_ACTIVE_DEFVALS,$ADODB_FETCH_MODE;
 
 		$activedb = $_ADODB_ACTIVE_DBS[$this->_dbat];
@@ -463,8 +463,8 @@ class ADODB_Active_Record {
 		$attr = array();
 		$keys = array();
 
-		switch($ADODB_ASSOC_CASE) {
-		case 0:
+		switch (ADODB_ASSOC_CASE) {
+		case ADODB_ASSOC_CASE_LOWER:
 			foreach($cols as $name => $fldobj) {
 				$name = strtolower($name);
 				if ($ADODB_ACTIVE_DEFVALS && isset($fldobj->default_value)) {
@@ -480,7 +480,7 @@ class ADODB_Active_Record {
 			}
 			break;
 
-		case 1:
+		case ADODB_ASSOC_CASE_UPPER:
 			foreach($cols as $name => $fldobj) {
 				$name = strtoupper($name);
 
@@ -510,7 +510,7 @@ class ADODB_Active_Record {
 				$attr[$name] = $fldobj;
 			}
 			foreach($pkeys as $k => $name) {
-				$keys[$name] = $cols[$name]->name;
+				$keys[$name] = $cols[strtoupper($name)]->name;
 			}
 			break;
 		}
@@ -813,7 +813,7 @@ class ADODB_Active_Record {
 	}
 
 	# useful for multiple record inserts
-	# see http://phplens.com/lens/lensforum/msgs.php?id=17795
+	# see PHPLens Issue No: 17795
 	function Reset()
 	{
 		$this->_where=null;
@@ -927,8 +927,6 @@ class ADODB_Active_Record {
 	// returns 0 on error, 1 on update, 2 on insert
 	function Replace()
 	{
-	global $ADODB_ASSOC_CASE;
-
 		$db = $this->DB();
 		if (!$db) {
 			return false;
@@ -968,14 +966,17 @@ class ADODB_Active_Record {
 			$pkey = array($pkey);
 		}
 
-		if ($ADODB_ASSOC_CASE == 0) {
-			foreach($pkey as $k => $v)
-				$pkey[$k] = strtolower($v);
-		}
-		elseif ($ADODB_ASSOC_CASE == 1) {
-			foreach($pkey as $k => $v) {
-				$pkey[$k] = strtoupper($v);
-			}
+		switch (ADODB_ASSOC_CASE) {
+			case ADODB_ASSOC_CASE_LOWER:
+				foreach ($pkey as $k => $v) {
+					$pkey[$k] = strtolower($v);
+				}
+				break;
+			case ADODB_ASSOC_CASE_UPPER:
+				foreach ($pkey as $k => $v) {
+					$pkey[$k] = strtoupper($v);
+				}
+				break;
 		}
 
 		$ok = $db->Replace($this->_table,$arr,$pkey);
