@@ -1,10 +1,10 @@
 <?php
 /*
 
-@version   v5.20.9  21-Dec-2016
+@version   v5.20.19  13-Dec-2020
 @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
 @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Latest version is available at http://adodb.sourceforge.net
+  Latest version is available at http://adodb.org/
 
   Released under both BSD license and Lesser GPL library license.
   Whenever there is any discrepancy between the two licenses,
@@ -137,7 +137,7 @@ class ADODB_Active_Record {
 	// if $options['new'] is true, we forget all relations
 	function __construct($table = false, $pkeyarr=false, $db=false, $options=array())
 	{
-	global $ADODB_ASSOC_CASE,$_ADODB_ACTIVE_DBS;
+	global $_ADODB_ACTIVE_DBS;
 
 		if ($db == false && is_object($pkeyarr)) {
 			$db = $pkeyarr;
@@ -410,7 +410,7 @@ class ADODB_Active_Record {
 	// update metadata
 	function UpdateActiveTable($pkeys=false,$forceUpdate=false)
 	{
-	global $ADODB_ASSOC_CASE,$_ADODB_ACTIVE_DBS , $ADODB_CACHE_DIR, $ADODB_ACTIVE_CACHESECS;
+	global $_ADODB_ACTIVE_DBS , $ADODB_CACHE_DIR, $ADODB_ACTIVE_CACHESECS;
 	global $ADODB_ACTIVE_DEFVALS, $ADODB_FETCH_MODE;
 
 		$activedb = $_ADODB_ACTIVE_DBS[$this->_dbat];
@@ -491,8 +491,8 @@ class ADODB_Active_Record {
 		$attr = array();
 		$keys = array();
 
-		switch($ADODB_ASSOC_CASE) {
-		case 0:
+		switch (ADODB_ASSOC_CASE) {
+		case ADODB_ASSOC_CASE_LOWER:
 			foreach($cols as $name => $fldobj) {
 				$name = strtolower($name);
 				if ($ADODB_ACTIVE_DEFVALS && isset($fldobj->default_value)) {
@@ -508,7 +508,7 @@ class ADODB_Active_Record {
 			}
 			break;
 
-		case 1:
+		case ADODB_ASSOC_CASE_UPPER:
 			foreach($cols as $name => $fldobj) {
 				$name = strtoupper($name);
 
@@ -1060,8 +1060,6 @@ class ADODB_Active_Record {
 	// returns 0 on error, 1 on update, 2 on insert
 	function Replace()
 	{
-	global $ADODB_ASSOC_CASE;
-
 		$db = $this->DB();
 		if (!$db) {
 			return false;
@@ -1097,7 +1095,7 @@ class ADODB_Active_Record {
 		}
 
 
-		switch ($ADODB_ASSOC_CASE == 0) {
+		switch (ADODB_ASSOC_CASE) {
 			case ADODB_ASSOC_CASE_LOWER:
 				foreach($pkey as $k => $v) {
 					$pkey[$k] = strtolower($v);
