@@ -6,7 +6,7 @@ global $ADODB_INCLUDED_LIB;
 $ADODB_INCLUDED_LIB = 1;
 
 /*
-  @version   v5.20.16  12-Jan-2020
+  @version   v5.20.19  13-Dec-2020
   @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
   @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
   Released under both BSD license and Lesser GPL library license.
@@ -177,7 +177,7 @@ function _adodb_replace(&$zthis, $table, $fieldArray, $keyCol, $autoQuote, $has_
 				if ($zthis->poorAffectedRows) {
 				/*
 				 The Select count(*) wipes out any errors that the update would have returned.
-				http://phplens.com/lens/lensforum/msgs.php?id=5696
+				PHPLens Issue No: 5696
 				*/
 					if ($zthis->ErrorNo()<>0) return 0;
 
@@ -441,7 +441,7 @@ function _adodb_getcount(&$zthis, $sql,$inputarr=false,$secs2cache=0)
 		}
 		// fix by alexander zhukov, alex#unipack.ru, because count(*) and 'order by' fails
 		// with mssql, access and postgresql. Also a good speedup optimization - skips sorting!
-		// also see http://phplens.com/lens/lensforum/msgs.php?id=12752
+		// also see PHPLens Issue No: 12752
 		$rewritesql = adodb_strip_order_by($rewritesql);
 	}
 
