@@ -1409,8 +1409,9 @@ class adoSchema {
 	function __construct( $db ) {
 		// Initialize the environment
 		$this->mgq = get_magic_quotes_runtime();
-		#set_magic_quotes_runtime(0);
-		ini_set("magic_quotes_runtime", 0);
+		if ($this->mgq !== false) {
+			ini_set('magic_quotes_runtime', 0 );
+		}
 
 		$this->db = $db;
 		$this->debug = $this->db->debug;
@@ -2377,8 +2378,9 @@ class adoSchema {
 	* @deprecated adoSchema now cleans up automatically.
 	*/
 	function Destroy() {
-		ini_set("magic_quotes_runtime", $this->mgq );
-		#set_magic_quotes_runtime( $this->mgq );
+		if ($this->mgq !== false) {
+			ini_set('magic_quotes_runtime', $this->mgq );
+		}
 	}
 }
 
