@@ -1,6 +1,6 @@
 <?php
 /*
-@version   v5.20.12  30-Mar-2018
+@version   v5.20.19  13-Dec-2020
 @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
 @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
   Released under both BSD license and Lesser GPL library license.
@@ -11,7 +11,7 @@
 
   Set tabs to 4 for best viewing.
 
-  Latest version of ADODB is available at http://php.weblogs.com/adodb
+  Latest version is available at http://adodb.org/
   ======================================================================
 
  This file provides PHP4 session management using the ADODB database
@@ -302,7 +302,6 @@ function adodb_sess_gc($maxlifetime) {
 	return true;
 }
 
-session_module_name('user');
 session_set_save_handler(
 	"adodb_sess_open",
 	"adodb_sess_close",
